@@ -5,18 +5,19 @@ http://www.esmvaltool.org
 CORE DEVELOPMENT TEAM AND CONTACTS:
   Birgit Hassler (Co-PI; DLR, Germany - birgit.hassler@dlr.de)
   Alistair Sellar (Co-PI; Met Office, UK - alistair.sellar@metoffice.gov.uk)
-  Bouwe Andela (Netherlands eScience Center, The Netherlands
-    - b.andela@esciencecenter.nl)
-  Veronika Eyring (DLR, Germany - veronika.eyring@dlr.de)
+  Bouwe Andela (Netherlands eScience Center, The Netherlands - b.andela@esciencecenter.nl)
   Lee de Mora (PML, UK - ledm@pml.ac.uk)
-  Niels Drost (Netherlands eScience Center, The Netherlands
-    - n.drost@esciencecenter.nl)
+  Niels Drost (Netherlands eScience Center, The Netherlands - n.drost@esciencecenter.nl)
+  Veronika Eyring (DLR, Germany - veronika.eyring@dlr.de)
   Bettina Gier (UBremen, Germany - gier@uni-bremen.de)
   Remi Kazeroni (DLR, Germany - remi.kazeroni@dlr.de)
   Nikolay Koldunov (AWI, Germany - nikolay.koldunov@awi.de)
   Axel Lauer (DLR, Germany - axel.lauer@dlr.de)
+  Saskia Loosveldt-Tomas (BSC, Spain - saskia.loosveldt@bsc.es)
+  Ruth Lorenz (ETH Zurich, Switzerland - ruth.lorenz@env.ethz.ch)
   Benjamin Mueller (LMU, Germany - b.mueller@iggf.geo.uni-muenchen.de)
   Valeriu Predoi (URead, UK - valeriu.predoi@ncas.ac.uk)
+  Mattia Righi (DLR, Germany - mattia.righi@dlr.de)
   Manuel Schlund (DLR, Germany - manuel.schlund@dlr.de)
   Breixo Solino Fernandez (DLR, Germany - breixo.solinofernandez@dlr.de)
   Javier Vegas-Regidor (BSC, Spain - javier.vegas@bsc.es)
@@ -24,9 +25,10 @@ CORE DEVELOPMENT TEAM AND CONTACTS:
 
 For further help, please read the documentation at
 http://docs.esmvaltool.org. Have fun!
-"""
+"""  # noqa: line-too-long pylint: disable=line-too-long
 # pylint: disable=import-outside-toplevel
 import logging
+from pathlib import Path
 
 import fire
 from pkg_resources import iter_entry_points
@@ -46,13 +48,32 @@ ______________________________________________________________________
 """ + __doc__
 
 
+def parse_resume(resume, recipe):
+    """Set `resume` to a correct value and sanity check."""
+    import os
+    if not resume:
+        return []
+    if isinstance(resume, str):
+        resume = resume.split(' ')
+    for i, resume_dir in enumerate(resume):
+        resume[i] = Path(os.path.expandvars(resume_dir)).expanduser()
+
+    # Sanity check resume directories:
+    current_recipe = recipe.read_text()
+    for resume_dir in resume:
+        resume_recipe = resume_dir / 'run' / recipe.name
+        if current_recipe != resume_recipe.read_text():
+            raise ValueError(f'Only identical recipes can be resumed, but '
+                             f'{resume_recipe} is different from {recipe}')
+    return resume
+
+
 def process_recipe(recipe_file, config_user):
     """Process recipe."""
     import datetime
     import os
     import shutil
 
-    from . import __version__
     from ._recipe import read_recipe_file
     if not os.path.isfile(recipe_file):
         import errno
@@ -63,8 +84,8 @@ def process_recipe(recipe_file, config_user):
     timestamp_format = "%Y-%m-%d %H:%M:%S"
 
     logger.info(
-        "Starting the Earth System Model Evaluation Tool v%s at time: %s UTC",
-        __version__, timestamp1.strftime(timestamp_format))
+        "Starting the Earth System Model Evaluation Tool at time: %s UTC",
+        timestamp1.strftime(timestamp_format))
 
     logger.info(70 * "-")
     logger.info("RECIPE   = %s", recipe_file)
@@ -107,8 +128,8 @@ def process_recipe(recipe_file, config_user):
     # End time timing
     timestamp2 = datetime.datetime.utcnow()
     logger.info(
-        "Ending the Earth System Model Evaluation Tool v%s at time: %s UTC",
-        __version__, timestamp2.strftime(timestamp_format))
+        "Ending the Earth System Model Evaluation Tool at time: %s UTC",
+        timestamp2.strftime(timestamp_format))
     logger.info("Time for running the recipe was: %s", timestamp2 - timestamp1)
 
 
@@ -225,7 +246,6 @@ class Recipes():
             Name of the recipe to get, including any subdirectories.
         """
         import shutil
-        from pathlib import Path
 
         from ._config import DIAGNOSTICS, configure_logging
         configure_logging(console_log_level='info')
@@ -303,13 +323,14 @@ class ESMValTool():
         for project, version in self._extra_packages.items():
             print(f'{project}: {version}')
 
-    @staticmethod
-    def run(recipe,
+    def run(self,
+            recipe,
             config_file=None,
+            resume_from=None,
             max_datasets=None,
             max_years=None,
             skip_nonexistent=False,
-            synda_download=False,
+            offline=None,
             diagnostics=None,
             check_level='default',
             **kwargs):
@@ -327,14 +348,17 @@ class ESMValTool():
         config_file: str, optional
             Configuration file to use. If not provided the file
             ${HOME}/.esmvaltool/config-user.yml will be used.
+        resume_from: list(str), optional
+            Resume one or more previous runs by using preprocessor output files
+            from these output directories.
         max_datasets: int, optional
             Maximum number of datasets to use.
         max_years: int, optional
             Maximum number of years to use.
         skip_nonexistent: bool, optional
             If True, the run will not fail if some datasets are not available.
-        synda_download: bool, optional
-            If True, the tool will try to download missing data using Synda.
+        offline: bool, optional
+            If True, the tool will not download missing data from ESGF.
         diagnostics: list(str), optional
             Only run the selected diagnostics from the recipe. To provide more
             than one diagnostic to filter use the syntax 'diag1 diag2/script1'
@@ -347,26 +371,14 @@ class ESMValTool():
             strict (fail if there are any warnings).
         """
         import os
-        import shutil
 
-        from ._config import (
-            DIAGNOSTICS,
-            configure_logging,
-            read_config_user_file,
-        )
+        from ._config import configure_logging, read_config_user_file
         from ._recipe import TASKSEP
         from .cmor.check import CheckLevels
+        from .esgf._logon import logon
 
-        if not os.path.exists(recipe):
-            installed_recipe = str(DIAGNOSTICS.recipes / recipe)
-            if os.path.exists(installed_recipe):
-                recipe = installed_recipe
-        recipe = os.path.abspath(os.path.expandvars(
-            os.path.expanduser(recipe)))
-
-        recipe_name = os.path.splitext(os.path.basename(recipe))[0]
-
-        cfg = read_config_user_file(config_file, recipe_name, kwargs)
+        recipe = self._get_recipe(recipe)
+        cfg = read_config_user_file(config_file, recipe.stem, kwargs)
 
         # Create run dir
         if os.path.exists(cfg['run_dir']):
@@ -378,12 +390,9 @@ class ESMValTool():
         log_files = configure_logging(output_dir=cfg['run_dir'],
                                       console_log_level=cfg['log_level'])
 
-        # log header
-        logger.info(HEADER)
-
-        logger.info("Using config file %s", config_file)
-        logger.info("Writing program log files to:\n%s", "\n".join(log_files))
+        self._log_header(cfg['config_file'], log_files)
 
+        cfg['resume_from'] = parse_resume(resume_from, recipe)
         cfg['skip-nonexistent'] = skip_nonexistent
         if isinstance(diagnostics, str):
             diagnostics = diagnostics.split(' ')
@@ -392,7 +401,11 @@ class ESMValTool():
             for pattern in diagnostics or ()
         }
         cfg['check_level'] = CheckLevels[check_level.upper()]
-        cfg['synda_download'] = synda_download
+        if offline is not None:
+            # Override config-user.yml from command line
+            cfg['offline'] = offline
+        if not cfg['offline']:
+            logon()
 
         def _check_limit(limit, value):
             if value is not None and value < 1:
@@ -409,19 +422,52 @@ class ESMValTool():
         with resource_usage_logger(pid=os.getpid(), filename=resource_log):
             process_recipe(recipe_file=recipe, config_user=cfg)
 
+        self._clean_preproc(cfg)
+        logger.info("Run was successful")
+
+    @staticmethod
+    def _clean_preproc(cfg):
+        import os
+        import shutil
+
         if os.path.exists(cfg["preproc_dir"]) and cfg["remove_preproc_dir"]:
             logger.info("Removing preproc containing preprocessed data")
             logger.info("If this data is further needed, then")
             logger.info("set remove_preproc_dir to false in config-user.yml")
             shutil.rmtree(cfg["preproc_dir"])
-        logger.info("Run was successful")
+
+    @staticmethod
+    def _get_recipe(recipe):
+        import os
+
+        from esmvalcore._config import DIAGNOSTICS
+        if not os.path.isfile(recipe):
+            installed_recipe = str(DIAGNOSTICS.recipes / recipe)
+            if os.path.isfile(installed_recipe):
+                recipe = installed_recipe
+        recipe = Path(os.path.expandvars(recipe)).expanduser().absolute()
+        return recipe
+
+    def _log_header(self, config_file, log_files):
+        from . import __version__
+        logger.info(HEADER)
+        logger.info('Package versions')
+        logger.info('----------------')
+        logger.info('ESMValCore: %s', __version__)
+        for project, version in self._extra_packages.items():
+            logger.info('%s: %s', project, version)
+        logger.info('----------------')
+        logger.info("Using config file %s", config_file)
+        logger.info("Writing program log files to:\n%s", "\n".join(log_files))
 
 
 def run():
     """Run the `esmvaltool` program, logging any exceptions."""
     import sys
 
-    # Workaroud to avoid using more for the output
+    from .exceptions import RecipeError
+
+    # Workaround to avoid using more for the output
 
     def display(lines, out):
         text = "\n".join(lines) + "\n"
@@ -433,6 +479,11 @@ def run():
         fire.Fire(ESMValTool())
     except fire.core.FireExit:
         raise
+    except RecipeError as exc:
+        # Hide the stack trace for RecipeErrors
+        logger.error("%s", exc)
+        logger.debug("Stack trace for debugging:", exc_info=True)
+        sys.exit(1)
     except Exception:  # noqa
         if not logger.handlers:
             # Add a logging handler if main failed to do so.
