@@ -9,24 +9,13 @@ from shutil import which
 import yamale
 
 from ._data_finder import get_start_end_year
+from .exceptions import InputFilesNotFound, RecipeError
 from .preprocessor import TIME_PREPROCESSORS, PreprocessingTask
 from .preprocessor._multimodel import STATISTIC_MAPPING
 
 logger = logging.getLogger(__name__)
 
 
-class RecipeError(Exception):
-    """Recipe contains an error."""
-    def __init__(self, msg):
-        super().__init__(self)
-        self.message = msg
-        self.failed_tasks = []
-
-    def __str__(self):
-        """Return message string."""
-        return self.message
-
-
 def ncl_version():
     """Check the NCL version."""
     ncl = which('ncl')
@@ -61,6 +50,8 @@ def recipe_with_schema(filename):
 
 def diagnostics(diags):
     """Check diagnostics in recipe."""
+    if diags is None:
+        raise RecipeError('The given recipe does not have any diagnostic.')
     for name, diagnostic in diags.items():
         if 'scripts' not in diagnostic:
             raise RecipeError(
@@ -101,7 +92,7 @@ def variable(var, required_keys):
                 missing, var.get('short_name'), var.get('diagnostic')))
 
 
-def data_availability(input_files, var, dirnames, filenames):
+def _log_data_availability_errors(input_files, var, dirnames, filenames):
     """Check if the required input data is available."""
     var = dict(var)
     if not input_files:
@@ -124,11 +115,45 @@ def data_availability(input_files, var, dirnames, filenames):
                 "Looked for files matching %s, but did not find any existing "
                 "input directory", filenames)
         logger.error("Set 'log_level' to 'debug' to get more information")
-        raise RecipeError(
+
+
+def _group_years(years):
+    """Group an iterable of years into easy to read text.
+
+    Example
+    -------
+    [1990, 1991, 1992, 1993, 2000] -> "1990-1993, 2000"
+    """
+    years = sorted(years)
+    year = years[0]
+    previous_year = year
+    starts = [year]
+    ends = []
+    for year in years[1:]:
+        if year != previous_year + 1:
+            starts.append(year)
+            ends.append(previous_year)
+        previous_year = year
+    ends.append(year)
+
+    ranges = []
+    for start, end in zip(starts, ends):
+        ranges.append(f"{start}" if start == end else f"{start}-{end}")
+
+    return ", ".join(ranges)
+
+
+def data_availability(input_files, var, dirnames, filenames, log=True):
+    """Check if input_files cover the required years."""
+    if log:
+        _log_data_availability_errors(input_files, var, dirnames, filenames)
+
+    if not input_files:
+        raise InputFilesNotFound(
             f"Missing data for {var['alias']}: {var['short_name']}")
 
-    # check time avail only for non-fx variables
     if var['frequency'] == 'fx':
+        # check time availability only for non-fx variables
         return
 
     required_years = set(range(var['start_year'], var['end_year'] + 1))
@@ -140,10 +165,11 @@ def data_availability(input_files, var, dirnames, filenames):
 
     missing_years = required_years - available_years
     if missing_years:
-        raise RecipeError(
-            "No input data available for years {} in files {}".format(
-                ", ".join(str(year) for year in sorted(missing_years)),
-                input_files))
+        missing_txt = _group_years(missing_years)
+
+        raise InputFilesNotFound(
+            "No input data available for years {} in files:\n{}".format(
+                missing_txt, "\n".join(str(f) for f in input_files)))
 
 
 def tasks_valid(tasks):
