@@ -6,7 +6,6 @@ from ..fix import Fix
 from ..shared import round_coordinates
 from .bnu_esm import Cl as BaseCl
 
-
 Cl = BaseCl
 
 
@@ -34,12 +33,11 @@ class Csoil(Fix):
 
 Cveg = Csoil
 
-
 Gpp = Csoil
 
 
-class Rlut(Fix):
-    """Fixes for rlut."""
+class AllVars(Fix):
+    """Fixes for all variables."""
 
     def fix_metadata(self, cubes):
         """Fix data.
@@ -56,61 +54,15 @@ class Rlut(Fix):
         Returns
         -------
         iris.cube.CubeList
-
         """
-        return round_coordinates(cubes, 3)
-
-
-class Rlutcs(Rlut):
-    """Fixes for rlutcs."""
-
-
-class Rsut(Rlut):
-    """Fixes for rsut."""
-
-
-class Rsutcs(Rlut):
-    """Fixes for rsutcs."""
-
-
-class Rlus(Rlut):
-    """Fixes for rlus."""
-
-
-class Rsus(Rlut):
-    """Fixes for rsus."""
-
-
-class Rsuscs(Rlut):
-    """Fixes for rsuscs."""
-
-
-class Rlds(Rlut):
-    """Fixes for rlds."""
-
-
-class Rldscs(Rlut):
-    """Fixes for rldscs."""
-
-
-class Rsds(Rlut):
-    """Fixes for rsds."""
-
-
-class Rsdscs(Rlut):
-    """Fixes for rsdscs."""
-
-
-class Rsdt(Rlut):
-    """Fixes for rsdt."""
+        return round_coordinates(cubes, decimals=3, coord_names=['latitude'])
 
 
 class So(Fix):
     """Fixes for so."""
 
     def fix_metadata(self, cubes):
-        """
-        Fix data.
+        """Fix data.
 
         Fixes discrepancy between declared units and real units
 
@@ -122,7 +74,6 @@ class So(Fix):
         Returns
         -------
         iris.cube.CubeList
-
         """
         self.get_cube_from_list(cubes).units = '1e3'
         return cubes
